@@ -1,5 +1,6 @@
 /* This file is part of Step.
    Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
 
    Step is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,7 +23,6 @@
 #include "worldgraphics.h"
 #include "stepgraphicsitem.h"
 #include <QGraphicsTextItem>
-#include <QAbstractItemModel>
 #include <QWidget>
 #include <QPointer>
 #include <KTextEdit>
@@ -34,8 +34,10 @@
 class KPlotWidget;
 class KPlotObject;
 class KToggleAction;
-class KAction;
-class KDialog;
+class QAction;
+class QDialog;
+class QDialogButtonBox;
+class QAbstractButton;
 class QSlider;
 class QLabel;
 
@@ -157,7 +159,7 @@ protected:
     NoteTextEdit*   _textEdit;
     KToolBar*       _toolBar;
 
-    KAction*       _actionColor;
+    QAction *       _actionColor;
     KToggleAction* _actionBold;
     KToggleAction* _actionItalic;
     KToggleAction* _actionUnderline;
@@ -171,8 +173,8 @@ protected:
     KFontAction*        _actionFont;
     KFontSizeAction*    _actionFontSize;
 
-    KAction* _actionInsertImage;
-    KAction* _actionInsertFormula;
+    QAction * _actionInsertImage;
+    QAction * _actionInsertFormula;
 
     friend class NoteTextEdit;
 };
@@ -246,13 +248,14 @@ public:
 protected slots:
     void clearGraph();
     void configureGraph();
-    void confApply();
+    void confApply(QAbstractButton *button);
     void confChanged();
 
 protected:
     StepCore::Graph* graph() const;
     Ui::WidgetConfigureGraph* _confUi;
-    KDialog*                  _confDialog;
+    QDialog*                  _confDialog;
+    QDialogButtonBox         *_buttonBox;
     bool                      _confChanged;
 };
 
@@ -292,15 +295,16 @@ public:
 
 protected slots:
     void configureMeter();
-    void confApply();
+    void confApply(QAbstractButton *button);
     void confChanged();
 
 protected:
     StepCore::Meter* meter() const;
-    KAction* _configureAction;
-    Ui::WidgetConfigureMeter* _confUi;
-    KDialog* _confDialog;
-    bool     _confChanged;
+    QAction * _configureAction;
+    Ui::WidgetConfigureMeter *_confUi;
+    QDialog                  *_confDialog;
+    QDialogButtonBox         *_buttonBox;
+    bool                      _confChanged;
 };
 
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -331,8 +335,8 @@ protected:
     QLabel*  _labelMax;
     QLabel*  _labelSource;
 
-    KAction* _incAction;
-    KAction* _decAction;
+    QAction * _incAction;
+    QAction * _decAction;
     QString  _incShortcut;
     QString  _decShortcut;
 
@@ -354,15 +358,16 @@ protected slots:
     void incTriggered();
     void decTriggered();
     void configureController();
-    void confApply();
+    void confApply(QAbstractButton *button);
     void confChanged();
 
 protected:
     StepCore::Controller* controller() const;
-    KAction* _configureAction;
-    Ui::WidgetConfigureController* _confUi;
-    KDialog* _confDialog;
-    bool     _confChanged;
+    QAction * _configureAction;
+    Ui::WidgetConfigureController *_confUi;
+    QDialog                       *_confDialog;
+    QDialogButtonBox              *_buttonBox;
+    bool                           _confChanged;
 };
 
 /////////////////////////////////////////////////////////////////////////////////////////
